Package 'StashSpectra'
| Title: |
Serialize and restore Spectra objects in interoperable file
formats |
| Description: |
The serialization mechanism of R allows to save and load R
data objects in a binary format, that can however not be read
by other programming languages or software. The StashSpectra
package implements the serialization methods from the MsStash
package for Spectra objects and its MsBackend classes. A
variety of different file formats and types, including HDF5 and
JSON-based formats defined by the Bioconductor *alabaster*
package are supported. The file type can be defined and
configured through a second argument `param` of the save/read
methods. |
| Authors: |
Johannes Rainer [aut, cre] (ORCID:
<https://orcid.org/0000-0002-6977-7147>),
Philippine Louail [aut] (ORCID:
<https://orcid.org/0009-0007-5429-6846>),
Laurent Gatto [ctb] (ORCID: <https://orcid.org/0000-0002-1520-2268>) |
| Maintainer: |
Johannes Rainer <[email protected]> |
| License: |
Artistic-2.0 |
| Version: |
0.97.0 |
| Built: |
2026-06-03 13:20:08 UTC |
| Source: |
https://github.com/rformassspectrometry/StashSpectra |
Help Index